@@ -191,6 +191,40 @@ class TestEG(ModelBaseTest):
         self.assertEqual(
             workspace.S(TestPerson).count(), 1)
 
+    def test_fast_forward_multiple_branches(self):
+        person1 = TestPerson({
+            'age': 1,
+            'name': 'Name'
+        })
+        person2 = TestPerson({
+            'age': 1,
+            'name': 'Name'
+        })
+
+        remote_workspace = self.mk_workspace(
+            name='%s_remote' % (self.id().lower(),),
+            index_prefix='%s_remote' % (self.workspace.index_prefix,))
+
+        # create a temporary branch, check it out and add another person
+        remote_repo = remote_workspace.repo
+        remote_workspace.save(person1, 'Saving person1.')
+        remote_repo.git.checkout('master', b='temp')
+        remote_workspace.save(person2, 'Saving person2.')
+
+        origin = self.workspace.repo.create_remote(
+            'origin', remote_workspace.working_dir)
+        # Fetch results in FetchInfo's from every branch
+        origin.fetch()
+
+        self.workspace.fast_forward(branch_name='master')
+        self.workspace.reindex(TestPerson)
+        self.assertEqual(
+            self.workspace.S(TestPerson).count(), 1)
+        self.workspace.fast_forward(branch_name='temp')
+        self.workspace.reindex(TestPerson)
+        self.assertEqual(
+            self.workspace.S(TestPerson).count(), 2)
+
     def test_fast_forward(self):
         person = TestPerson({
             'age': 1,
@@ -211,6 +245,44 @@ class TestEG(ModelBaseTest):
         self.assertEqual(
             self.workspace.S(TestPerson).count(), 1)
 
+    def test_fast_forward_with_multiple_remotes(self):
+        person = TestPerson({
+            'age': 1,
+            'name': 'Name',
+        })
+        self.origin_workspace = self.mk_workspace(
+            name='%s-origin' % (self.id().lower()),
+            index_prefix='origin')
+        self.origin_workspace.save(person, 'Saving origin upstream')
+
+        person2 = TestPerson({
+            'age': 2,
+            'name': 'Another Name',
+        })
+        self.upstream_workspace = self.mk_workspace(
+            name='%s-upstream' % (self.id().lower()),
+            index_prefix='upstream')
+        self.upstream_workspace.save(person2, 'Saving upstream')
+
+        repo = self.workspace.repo
+        repo.create_remote(
+            'origin', self.origin_workspace.working_dir)
+        repo.create_remote(
+            'upstream', self.upstream_workspace.working_dir)
+
+        self.assertEqual(
+            self.workspace.S(TestPerson).count(), 0)
+
+        self.workspace.fast_forward()
+        self.workspace.reindex(TestPerson)
+        self.assertEqual(
+            self.workspace.S(TestPerson).count(), 1)
+
+        self.workspace.fast_forward(remote_name='upstream')
+        self.workspace.reindex(TestPerson)
+        self.assertEqual(
+            self.workspace.S(TestPerson).count(), 2)
+
     def test_case_sensitivity(self):
         workspace = self.workspace
         workspace.setup_mapping(TestPage)
